<?php
namespace App\Http\Controllers\AdminDashboard;
use App\Http\Controllers\Controller;

use App\Models\Images;
use App\Models\OpenGraph;
use App\Models\Pages;
use Illuminate\Http\Request;
use App\Http\Requests;
use App\Models\Album;
use App\Models\Album_images;

class AlbumController extends Controller{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index(){
        $album=Album::first();
       // dd($album->images[0]->name);
        return view("dashboard.album.index")->with('album',$album);
    }
    public function create(){
        $album=Album::first();
        if($album){
            return redirect("/adminDashboard/album/edit/".$album->id);
        }else{
            return view("dashboard.album.create");
        }

    }

    public function store(Request $request){
        $data = $request->validate([
            'alt' => 'required',
            'image_id.*' => 'required|image|mimes:jpeg,png',
            'main_image' => 'required|image|mimes:jpeg,png',
        ]);
        //$url=$request->url==null?$request->title_en:$request->url;
        $url=\Str::random(32);
        //---- store main image to use it in open graph (SEO) ---------
        $image=null;
        if($request->main_image){
            $image_name=time()."_".$request->main_image->getClientOriginalName();
            $request->main_image->storeAs("/storage/uploads/album",$image_name);
            $image=Images::create(['name'=>$image_name,'dir_name'=>'album','alt'=>$request->alt]);
        }
        //-----------------
        //---------- SEO --------------------
        //------open graph ---------
        $og=OpenGraph::create(['og_image_id'=>$image->id,'og_title'=>'first-album','og_description'=>null,
            'og_url'=>$url,'og_type'=>$request->main_image->getClientOriginalExtension(),'created_by'=>auth()->user()->id
        ]);
        //----------------------

        //------------ page -----------
        $page=Pages::create(['is_main_page'=>null,'description'=>null,'url'=>$url,
            'name'=>'first-album','og_id'=>$og->id,'created_by'=>auth()->user()->id
        ]);
        //-------------------
        //-----end SEO-----------
        //---- album ----------
        $album_id = Album::create(['image_id'=>$image->id,'url'=>$url,'og_id'=>$og->id,'page_id'=>$page->id,'created_by' => auth()->user()->id])->id;
        $image_name = [];
        if ($request->image_id) {
            foreach ($request->image_id as $images):
                $image_name = time() . "_" . $images->getClientOriginalName();
                $images->storeAs("/storage/uploads/album", $image_name);
                Album_images::create(['album_id' => $album_id, 'image' => $image_name, 'alt' => $request->alt]);
            endforeach;
        }
        //----------------------
        return redirect("/adminDashboard/album");
    }

    public function edit($id){
        $album=Album::find($id);
        return view("dashboard.album.edit")->with('album',$album);
    }

    public function update(Request $request,$id){
        $album = Album::find($id);
        $request->validate([
            'alt' => 'required',
            'image_id.*' => 'image|mimes:jpeg,png',
            'main_image' => 'image|mimes:jpeg,png',
        ]);
        $url=\Str::random(32);
        if ($request->image_id) {
            $album->update(['url'=>$url,'created_by' => auth()->user()->id]);
            OpenGraph::where('id',$album->og_id)->update(['og_url'=>$url]);
            Pages::where('id',$album->page_id)->update(['url'=>$url]);
            foreach ($album->images as $images):
                $image_path = public_path('/storage/uploads/album/' . $images->image);
                //echo $image_path;
                if (\File::exists($image_path)) {
                    unlink($image_path);
                } else {
                }
            endforeach;
            Album_images::where('album_id', $id)->delete();
            foreach ($request->image_id as $images):
                $image_name = time() . "_" . $images->getClientOriginalName();
                $images->storeAs("/storage/uploads/album", $image_name);
                Album_images::create(['album_id' => $id, 'image' => $image_name, 'alt' => $request->alt]);
            endforeach;
        }
        if($request->main_image){
            $image_path = public_path('/storage/uploads/album/'.$album->image->name);
            //echo $image_path;
            if (\File::exists($image_path)) {
                unlink($image_path);
            } else {}
            $image_name=time()."_".$request->main_image->getClientOriginalName();
            $request->main_image->storeAs("/storage/uploads/album",$image_name);
            Images::where("id",$album->image_id)->update(['name'=>$image_name,'dir_name'=>'album','alt'=>$request->alt]);
        }
        return redirect("/adminDashboard/album");
    }


    public function show($id){
        $album=Album::find($id);
        /*foreach ($album->images as $mm):
            echo $mm->image;
            endforeach;*/
        return view("dashboard.album.show")->with("album",$album);
    }


    public function destroyAlbumImage(Request $request,$id){
        $image=$request->image;
        Album_images::where("album_id",$id)->where("image",$image)->delete();
        return back();
    }


    public function storeAlbumImage(Request $request,$id){
        $request->validate([
            'album_im'=>'bail:required|image|mimes:jpeg,png'
        ]);
        if($request->album_im){
            $image_name=time()."_".$request->album_im->getClientOriginalName();
            $request->album_im->storeAs("/storage/uploads/album",$image_name);
            Album_images::create(['album_id'=>$id,'image'=>$image_name]);
            return back();
        }
        //dd($request->file('product_im'));

    }
}
