<?php
namespace App\Http\Controllers\AdminDashboard;
use App\Http\Controllers\Controller;
use App\Models\Images;
use App\Models\OpenGraph;
use App\Models\Pages;
use Illuminate\Http\Request;
use App\Http\Requests;
use App\Models\Product;
//use App\Models\Images;
use App\Models\Product_images;
use App\Models\Category;

class ProductController extends Controller{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function index(){
        $products=Product::all();
        //dd($products[0]->main_image);
        return view("dashboard.product.index")->with("products",$products);
    }
    public function create(){
        $categories=Category::all();
        return view("dashboard.product.create")->with('categories',$categories);
    }
    public function store(Request $request){
        $data = $request->validate([
            'title_en' => 'required',
            'description_en' => 'required',
            'specification_en' => 'required',
            'image_id.*' => 'image|mimes:jpeg,png',
            'main_image' => 'required|image|mimes:jpeg,png',
            'alt' => 'required',
            'url' => 'unique:product,url',
            'title_ar' => 'required',
            'category_id' => 'required|numeric',
            'description_ar' => 'required',
            'specification_ar' => 'required',
        ]);
        $url=$request->url==null?str_slug($request->title_en,'-'):$request->url;
        $image=null;
        if ($request->main_image) {
            $request->main_image->storeAs("/storage/uploads/product", time() . "_" . $request->main_image->getClientOriginalName());
            $image_name= time() . "_" . $request->main_image->getClientOriginalName();
            $image=Images::create(['name'=>$image_name,'dir_name'=>'product','alt'=>$request->alt]);
        }
        //-----------------
        //---------- SEO --------------------
        //------open graph ---------
        $og=OpenGraph::create(['og_image_id'=>$image->id,'og_title'=>$request->title_en,'og_description'=>$request->description_en,
            'og_url'=>$url,'og_type'=>$request->main_image->getClientOriginalExtension(),'created_by'=>auth()->user()->id
        ]);
        //----------------------

        //------------ page -----------
        $page=Pages::create(['is_main_page'=>null,'description'=>$request->description_en,'url'=>$url,
            'name'=>$request->title_en,'og_id'=>$og->id,'created_by'=>auth()->user()->id
        ]);
        //-------------------
        //-----end SEO-----------
        Product::insert(['image_id'=>$image->id,'url'=>$url,'category_id' => $request->category_id,'og_id'=>$og->id,'page_id'=>$page->id,
            'created_by' => auth()->user()->id]);
        $product = Product::orderBy('id', 'DESC')->limit(1)->first();
        \App\Models\Arabic\Product::create(['product_id' => $product->id, 'title' => $request->title_ar,
            'description' => $request->description_ar, 'specification' => $request->specification_ar,
        ]);
        \App\Models\English\Product::create(['product_id' => $product->id, 'title' => $request->title_en,
            'description' => $request->description_en, 'specification' => $request->specification_en,
        ]);

        //insert images------------
        $images = $request->image_id;
        $images_name = [];
        if (is_array($images)) {
            foreach ($images as $dataImages):
                $images_name = time() . "_" . $dataImages->getClientOriginalName();
                //echo($images_name);
                $dataImages->storeAs("/storage/uploads/product", $images_name);
                Product_images::create(['product_id' => $product->id, 'image' => $images_name]);
            endforeach;
        } else {
            echo 'invalid action you shouldn`t change that value';
        }
        return redirect("/adminDashboard/product");
    }

    public function destroy($id){
        $product=Product::find($id);
        $product->delete();
        return redirect("/adminDashboard/product");
    }

    public function edit($id){
        $product=Product::find($id);
        $categories=Category::all();
        return view("dashboard.product.edit")->with('product',$product)->with('categories',$categories);
    }

    public function update(Request $request,$id){
        $product = Product::find($id);
        $data = $request->validate([
            'title_en' => 'required',
            'description_en' => 'required',
            'specification_en' => 'required',
            'image_id.*' => 'image|mimes:jpeg,png',
            'main_image' => 'image|mimes:jpeg,png',
            'alt' => 'required',
            'url' => 'unique:product,url,'.$id,
            'title_ar' => 'required',
            'category_id' => 'required|numeric',
            'description_ar' => 'required',
            'specification_ar' => 'required',
        ]);
        //---delete main product image file
        $url=$request->url==null?str_slug($request->title_en,'-'):$request->url;
        if ($request->main_image) {
            $request->main_image->storeAs("/storage/uploads/product", time() . "_" . $request->main_image->getClientOriginalName());
            $image_path = public_path("/storage/uploads/product/" . $product->main_image);
            if (\File::exists($image_path)) {
                unlink($image_path);
            } else {

            }
        }
        //----------------------------------------
        //---- update product main image
        Images::where('id',$product->image_id)->update(['name'=>$request->main_image ? time() . "_" . $request->main_image->getClientOriginalName() : $product->main_image->name,
            'alt'=>$request->alt
        ]);
        //--------------------------------------------
        //--------- update product
        Product::where('id', $id)->update(['url'=>$url,'category_id' => $request->category_id, 'created_by' => auth()->user()->id]);
        //--------------
        //------------update open graph and page (SEO)
        OpenGraph::where('id',$product->og_id)->update(['og_url'=>$url]);
        Pages::where('id',$product->page_id)->update(['url'=>$url]);
        //------------------------
        \App\Models\Arabic\Product::where("product_id", $id)->update(['title' => $request->title_ar,
            'description' => $request->description_ar, 'specification' => $request->specification_ar,
        ]);
        \App\Models\English\Product::where("product_id", $id)->update(['title' => $request->title_en,
            'description' => $request->description_en, 'specification' => $request->specification_en,
        ]);
        $images = $request->image_id;
        $images_name = [];
        if (is_array($images)) {
            foreach ($product->image as $product_images):
                $image_path = public_path("/storage/uploads/product/" . $product_images->image);
                if (\File::exists($image_path)) {
                    unlink($image_path);
                } else {
                }
                //echo $product_images->image;
            endforeach;
            Product_images::where("product_id", $id)->delete();
            foreach ($images as $dataImages):
                $images_name = time() . "_" . $dataImages->getClientOriginalName();
                //echo($images_name);
                $dataImages->storeAs("/storage/uploads/product", $images_name);
                Product_images::create(['product_id' => $id, 'image' => $images_name,'alt'=>$request->alt]);
            endforeach;
        } else {
            echo 'invalid action you shouldn`t change that value';
        }
        return redirect("/adminDashboard/product");
    }
    public function show($id){
        $product=Product::find($id);
        return view("dashboard.product.show")->with("product",$product);
    }
    public function destroyProductImage(Request $request,$id){
        $image=$request->image;
        Product_images::where("product_id",$id)->where("image",$image)->delete();
        return back();
    }
    public function storeProductImage(Request $request,$id){
        $request->validate([
            'product_im'=>'bail:required|image|mimes:jpeg,png'
        ]);
        if($request->product_im){
            $image_name=time()."_".$request->product_im->getClientOriginalName();
            $request->product_im->storeAs("/storage/uploads/product",$image_name);
            Product_images::create(['product_id'=>$id,'image'=>$image_name]);
            return back();
        }
       //dd($request->file('product_im'));

    }

}
